***********************
Directed Acyclic Graphs
***********************

.. automodule:: networkx.algorithms.dag
.. autosummary::
   :toctree: generated/

   ancestors
   descendants
   topological_sort
   topological_generations
   all_topological_sorts
   lexicographical_topological_sort
   is_directed_acyclic_graph
   is_aperiodic
   transitive_closure
   transitive_closure_dag
   transitive_reduction
   antichains
   dag_longest_path
   dag_longest_path_length
   dag_to_branching
